@@ -9,7 +9,7 @@ import numpy as np   #for calculaiton
 import matplotlib as mpl
 import matplotlib.pyplot as plt
 import mplcursors
-import dill
+
 # from openpyxl import load_workbook
 from datetime import datetime
 from collections import defaultdict
@@ -50,19 +50,15 @@ class explore:
         allFile_l = []    
         for subdir, dirs, files in os.walk(self.rootdir):
             for file in files:
-                #exclude configuration file no matter how
-                if 'config' not in file:
-                    #if file has extension
-                    if self.ext != ('',) and self.ext != ():
-                        pat = ".*\.%s"%self.ext
-                        if re.match(pat,file):
-                            if file.split('.')[0] >= str(start) and file.split('.')[0] <= str(end):
-                                allFile_l.append(os.path.join(subdir,file))
-                    #if file has no extension
-                    elif not re.match(".*\..*", file):
-                        if file.split('_')[0] >= str(start) and file.split('_')[0] <= str(end):
-                            allFile_l.append(os.path.join(subdir,file))
-        
+                #if file is *.txt file
+                pat = ".*\.txt"
+                if re.match(pat,file):
+                    if file.split('.')[0] >= str(start) and file.split('.')[0] <= str(end):
+                        allFile_l.append(os.path.join(subdir,file))
+                #if file has no extension
+                if not re.match(".*\..*", file):
+                    if file.split('_')[0] >= str(start) and file.split('_')[0] <= str(end):
+                        allFile_l.append(os.path.join(subdir,file))
         if display:
             if self.p:
                 print ('Found %s %s files'%(len(allFile_l),self.ext))
@@ -449,7 +445,7 @@ class Ui_MainWindow(object):
         self.label_sessiondur.setText(_translate("MainWindow", "Session duration (mins)"))
         self.plot.setText(_translate("MainWindow", "Plot"))
         self.tabs.setTabText(self.tabs.indexOf(self.dataexplorer), _translate("MainWindow", "Data Explorer"))
-        self.info_label.setText(_translate("MainWindow", "Current version v3.0.7 \n"
+        self.info_label.setText(_translate("MainWindow", "Current version v3.0.9 \n"
 "Created by Yifeng Cheng, Ph.D. \n"
 "Contact:\n"
 "(979)571-8531\n"
@@ -519,7 +515,7 @@ class MyApp (QtWidgets.QMainWindow, Ui_MainWindow):
         for n, f in enumerate(datafile_list):
             #get all data from this session
             _, func_out = medpc_read(f, working_var_label, skipold = skipexist, override = replace_file, replace = replace_data, log = func_out) #pass TS_df_tree to an anonymous variable
-            self.medpctoexcel_progressbar.setValue(n/total*100)
+            self.medpctoexcel_progressbar.setValue(int((n/total)*100))
         self.medpctoexcel_progressbar.setValue(100)
         self.log.append(func_out)
 
